@@ -3,8 +3,9 @@ from pathlib import Path
 
 import pytest
 
+from pytest_snapshot._utils import simple_version_parse
 from pytest_snapshot.plugin import _file_encode
-from tests.utils import assert_pytest_passes
+from tests.utils import assert_pytest_passes, runpytest_with_assert_mode
 
 
 @pytest.fixture
@@ -25,7 +26,7 @@ def test_assert_match_with_external_snapshot_path(testdir, basic_case_dir):
     result = testdir.runpytest('-v')
     result.stdout.fnmatch_lines([
         '*::test_sth FAILED*',
-        "E* AssertionError: Snapshot path not_case_dir?snapshot1.txt is not in case_dir",
+        "E* ValueError: Snapshot path not_case_dir?snapshot1.txt is not in case_dir",
     ])
     assert result.ret == 1
 
@@ -49,17 +50,18 @@ def test_assert_match_success_bytes(testdir, basic_case_dir):
     assert_pytest_passes(testdir)
 
 
-def test_assert_match_failure_string(testdir, basic_case_dir):
+def test_assert_match_failure_string(request, testdir, basic_case_dir):
     testdir.makepyfile(r"""
         def test_sth(snapshot):
             snapshot.snapshot_dir = 'case_dir'
             snapshot.assert_match('the INCORRECT value of snapshot1.txt\n', 'snapshot1.txt')
     """)
-    result = testdir.runpytest('-v')
+    result = runpytest_with_assert_mode(testdir, request, '-v', '--assert=rewrite')
     result.stdout.fnmatch_lines([
         '*::test_sth FAILED*',
-        ">* raise AssertionError(snapshot_diff_msg)",
+        r">* snapshot.assert_match('the INCORRECT value of snapshot1.txt\n', 'snapshot1.txt')",
         'E* AssertionError: value does not match the expected value in snapshot case_dir?snapshot1.txt',
+        "E*   (run pytest with --snapshot-update to update snapshots)",
         "E* assert * == *",
         "E* - the valuÉ of snapshot1.txt",
         "E* ?         ^",
@@ -69,18 +71,19 @@ def test_assert_match_failure_string(testdir, basic_case_dir):
     assert result.ret == 1
 
 
-def test_assert_match_failure_bytes(testdir, basic_case_dir):
+def test_assert_match_failure_bytes(request, testdir, basic_case_dir):
     testdir.makepyfile(r"""
         import os
         def test_sth(snapshot):
             snapshot.snapshot_dir = 'case_dir'
             snapshot.assert_match(b'the INCORRECT value of snapshot1.txt' + os.linesep.encode(), 'snapshot1.txt')
     """)
-    result = testdir.runpytest('-v')
+    result = runpytest_with_assert_mode(testdir, request, '-v', '--assert=rewrite')
     result.stdout.fnmatch_lines([
         r'*::test_sth FAILED*',
-        r">* raise AssertionError(snapshot_diff_msg)",
+        r">* snapshot.assert_match(b'the INCORRECT value of snapshot1.txt' + os.linesep.encode(), 'snapshot1.txt')",
         r'E* AssertionError: value does not match the expected value in snapshot case_dir?snapshot1.txt',
+        r'E*   (run pytest with --snapshot-update to update snapshots)',
         r"E* assert * == *",
         r"E* At index 4 diff: * != *",
         r"E* Full diff:",
@@ -90,6 +93,36 @@ def test_assert_match_failure_bytes(testdir, basic_case_dir):
     assert result.ret == 1
 
 
+@pytest.mark.skipif(simple_version_parse(pytest.__version__) < (5, 0, 0), reason="consecutive flag not supported.")
+def test_assert_match_failure_assert_plain(request, testdir, basic_case_dir):
+    """
+    Testing plugin behavior when users run "pytest --assert=plain" is complicated and fragile since the outer pytest
+    and inner pytest affect one another. To get around this, we call pytest in a subprocess.
+
+    If you wish to run this test in a debugger, consider replacing `runpytest_subprocess` with `runpytest` and running
+    the test with "--assert=plain".
+    """
+    testdir.makepyfile(r"""
+        def test_sth(snapshot):
+            snapshot.snapshot_dir = 'case_dir'
+            snapshot.assert_match('the INCORRECT value of snapshot1.txt\n', 'snapshot1.txt')
+    """)
+
+    result = runpytest_with_assert_mode(testdir, request, '-v', '--assert=plain')
+    result.stdout.fnmatch_lines([
+        '*::test_sth FAILED*',
+    ])
+    # Use consecutive=True to verify that --assert=rewrite was not triggered somehow.
+    result.stdout.fnmatch_lines([
+        r">* snapshot.assert_match('the INCORRECT value of snapshot1.txt\n', 'snapshot1.txt')",
+        'E* AssertionError: value does not match the expected value in snapshot case_dir?snapshot1.txt',
+        'E*   (run pytest with --snapshot-update to update snapshots)',
+        '',
+        '*test_assert_match_failure_assert_plain.py:*: AssertionError',
+    ], consecutive=True)
+    assert result.ret == 1
+
+
 def test_assert_match_invalid_type(testdir, basic_case_dir):
     testdir.makepyfile(r"""
         def test_sth(snapshot):
@@ -169,9 +202,11 @@ def test_assert_match_update_existing_snapshot(testdir, basic_case_dir, case_dir
     result.stdout.fnmatch_lines([
         '*::test_sth PASSED*',
         '*::test_sth ERROR*',
-        "E* AssertionError: Snapshot directory was modified: case_dir",
-        'E*   Updated snapshots:',
-        'E*     snapshot1.txt',
+        '* ERROR at teardown of test_sth *',
+        'Snapshot directory was modified: case_dir',
+        '  (verify that the changes are expected before committing them to version control)',
+        '  Updated snapshots:',
+        '    snapshot1.txt',
     ])
     assert result.ret == 1
 
@@ -195,9 +230,11 @@ def test_assert_match_update_existing_snapshot_and_exception_in_test(testdir, ba
     result.stdout.fnmatch_lines([
         '*::test_sth FAILED*',
         '*::test_sth ERROR*',
-        "E* AssertionError: Snapshot directory was modified: case_dir",
-        'E*   Updated snapshots:',
-        'E*     snapshot1.txt',
+        '* ERROR at teardown of test_sth *',
+        'Snapshot directory was modified: case_dir',
+        '  (verify that the changes are expected before committing them to version control)',
+        '  Updated snapshots:',
+        '    snapshot1.txt',
         'E* assert False',
     ])
     assert result.ret == 1
@@ -213,9 +250,11 @@ def test_assert_match_create_new_snapshot(testdir, basic_case_dir):
     result.stdout.fnmatch_lines([
         '*::test_sth PASSED*',
         '*::test_sth ERROR*',
-        "E* Snapshot directory was modified: case_dir",
-        'E*   Created snapshots:',
-        'E*     sub_dir?new_snapshot1.txt',
+        '* ERROR at teardown of test_sth *',
+        'Snapshot directory was modified: case_dir',
+        '  (verify that the changes are expected before committing them to version control)',
+        '  Created snapshots:',
+        '    sub_dir?new_snapshot1.txt',
     ])
     assert result.ret == 1
 
@@ -231,9 +270,11 @@ def test_assert_match_create_new_snapshot_in_default_dir(testdir):
     result.stdout.fnmatch_lines([
         '*::test_sth PASSED*',
         '*::test_sth ERROR*',
-        "E* Snapshot directory was modified: snapshots?test_assert_match_create_new_snapshot_in_default_dir?test_sth",
-        'E*   Created snapshots:',
-        'E*     sub_dir?new_snapshot1.txt',
+        '* ERROR at teardown of test_sth *',
+        'Snapshot directory was modified: snapshots?test_assert_match_create_new_snapshot_in_default_dir?test_sth',
+        '  (verify that the changes are expected before committing them to version control)',
+        '  Created snapshots:',
+        '    sub_dir?new_snapshot1.txt',
     ])
     assert result.ret == 1
     assert testdir.tmpdir.join(
@@ -304,7 +345,7 @@ def test_assert_match_edge_cases(testdir, basic_case_dir, tested_value):
     assert_pytest_passes(testdir)  # assert that snapshot update worked
 
 
-def test_assert_match_unsupported_value_existing_snapshot(testdir, basic_case_dir):
+def test_assert_match_unsupported_value_existing_snapshot(request, testdir, basic_case_dir):
     """
     Test that when running tests without --snapshot-update, we don't tell the user that the value is unsupported.
     We instead tell the user that the value does not equal the snapshot. This behaviour is more helpful.
@@ -315,7 +356,7 @@ def test_assert_match_unsupported_value_existing_snapshot(testdir, basic_case_di
             snapshot.snapshot_dir = 'case_dir'
             snapshot.assert_match('\r', 'newline.txt')
     """)
-    result = testdir.runpytest('-v')
+    result = runpytest_with_assert_mode(testdir, request, '-v', '--assert=rewrite')
     result.stdout.fnmatch_lines([
         '*::test_sth FAILED*',
         'E* AssertionError: value does not match the expected value in snapshot case_dir?newline.txt',
